<?php
namespace Teknisa\EST\Modules\EstoqueCego\Factories;

use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Est91000ProgramacaoDoInventarioCegoFactory {
    protected $connection;
    protected $entityManager;

    public function __construct ($entityManager) {
        $this->connection = $entityManager->getConnection();
		$this->entityManager = $entityManager;
    }
    
    public function insertLote($params) {
        $sql = "INSERT INTO LOTE
                (CDFILIAL, NRLOTEESTQ, NRSUBLOTE, CDPRODUTO, IDSTATLOTE, DTENTRLOTE)
                (SELECT :CDFILIAL CDFILIAL, :NRLOTEESTQ NRLOTEESTQ, :NRSUBLOTE NRSUBLOTE, :CDPRODUTO CDPRODUTO,
                'L' IDSTATLOTE, SYSDATE DTENTRLOTE
                FROM PARAMGERAL
                MINUS
                SELECT CDFILIAL, NRLOTEESTQ, NRSUBLOTE, :CDPRODUTO CDPRODUTO, 'L', SYSDATE
                FROM LOTE
                WHERE :CDFILIAL   =  CDFILIAL     AND
                      :NRLOTEESTQ =  NRLOTEESTQ   AND
                      :NRSUBLOTE  =  NRSUBLOTE    AND
                      :CDPRODUTO  =  CDPRODUTO)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function checkInventoryActualDate($params) {
        $sql = "SELECT DTCONTAGEM,IDSITESTCEGO
                  FROM INVENTESTCEGO I
                 WHERE (CDFILIAL = :CDFILIAL)
                   AND (DTCONTAGEM = :DTCONTAGEM)";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $result = $std->fetchAll();
        
        return $result;
    }
    
    public function deleteAllInventory($params) {
        $sql = "DELETE FROM INVENTESTCEGO
                 WHERE CDFILIAL = :CDFILIAL
                   AND DTCONTAGEM = :DTCONTAGEM";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function getCDFILISUBGR($params) {
        $sql = "SELECT DISTINCT CDFILISUBGR
                  FROM PRSUBGRPROD
                 WHERE CDGRUPPROD = :CDGRUPPROD
                 ORDER BY CDFILISUBGR ASC";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $result = $std->fetch();
        
        return $result;
    }
    
    public function getProductsInfo($params,$type) {
        switch($type){
            case "byGroupOnly":
                $sql = "SELECT DISTINCT CDPRODMOVI, CDALMOXARIFE,
                               CDLOCALESTOQ, NRLOTEESTQ, NRSUBLOTE
                          FROM ITLANCTOEST I, PRODUTO P, GRUPPROD GR,
                               SUBGRUPPROD SG, PRSUBGRPROD AN
                         WHERE CDFILIMOVI      = :CDFILIAL
                           AND NVL(IDEVOLESTOQ,'S') = 'S'
                           AND DTLANCMOVI BETWEEN :DTINICIAL AND :DTFINAL
                           AND CDARVPROD BETWEEN :CDPRODINI AND :CDPRODFIN
                           AND (P.CDPRODUTO    = CDPRODMOVI)
                           AND (CDFILISUBGR    = :CDFILISUBGR)
                           AND (GR.CDGRUPPROD  = :CDGRUPPROD)
                           AND (GR.CDGRUPPROD  = SG.CDGRUPPROD)
                           AND (SG.CDSUBGRPROD = AN.CDSUBGRPROD)
                           AND (I.CDPRODMOVI   = AN.CDPRODUTO)
                           AND (SG.CDGRUPPROD  = AN.CDGRUPPROD)
                         ORDER BY CDALMOXARIFE, CDLOCALESTOQ";
                break;
            case "byProductsOnly":
                $sql = "SELECT DISTINCT I.CDPRODMOVI, I.CDALMOXARIFE, I.CDLOCALESTOQ,
                               I.NRLOTEESTQ, I.NRSUBLOTE
                          FROM ITLANCTOEST I, PRODUTO P, PRODFILI F
                         WHERE CDFILIMOVI            = :CDFILIAL
                           AND NVL(IDEVOLESTOQ,'S')  = 'S'
                           AND (DTLANCMOVI BETWEEN :DTINICIAL AND :DTFINAL)
                           AND (CDARVPROD BETWEEN :CDPRODINI AND :CDPRODFIN)
                           AND (P.CDPRODUTO          = CDPRODMOVI)
                           AND (I.CDPRODMOVI         = F.CDPRODUTO)
                           AND (CDFILIMOVI           = F.CDFILIAL)
                           AND (NVL(IDCNTRESTOQ,'S') = 'S')
                         ORDER BY I.CDALMOXARIFE, I.CDLOCALESTOQ";
                
                break;
            case "byGroupWithParamChecked":
                $sql = "";
                break;
            case "byProductsWithParamChecked":
                $sql = "";
                break;
            default:
                break;
        }
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $result = $std->fetchAll();
        return $result;
    }
    
    public function checkHolidays($params) {
        $sql = "SELECT TO_CHAR(DTFERIFILI,'DDMMYYYY') AS DTFERIFILI
                  FROM FERIFILI
                 WHERE (CDFILIAL = :CDFILIAL)
                   AND (DTFERIFILI = :DTCONTAGEM) ORDER BY DTFERIFILI";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $result = $std->fetchAll();
        
        return $result;
    }
}